@@ -13,6 +13,7 @@ import argparse
 import cppcheckdata
 import sys
 import re
+import subprocess
 
 VERIFY = ('-verify' in sys.argv)
 VERIFY_EXPECTED = []
@@ -195,7 +196,9 @@ def int31(data, platform):
         if to_value_type is None or not from_values:
             continue
         bits = None
-        if to_value_type.type == 'char':
+        if token.valueType.pointer > 0:
+            bits = platform.pointer_bit
+        elif to_value_type.type == 'char':
             bits = platform.char_bit
         elif to_value_type.type == 'short':
             bits = platform.short_bit
@@ -399,6 +402,8 @@ if __name__ == '__main__':
     parser = get_args_parser()
     args = parser.parse_args()
 
+    path_premium_addon = cppcheckdata.get_path_premium_addon()
+
     if args.verify:
         VERIFY = True
 
@@ -411,6 +416,14 @@ if __name__ == '__main__':
         if not args.quiet:
             print('Checking %s...' % dumpfile)
 
+        if path_premium_addon:
+            premium_command = [path_premium_addon, '--cert', dumpfile]
+            if args.cli:
+                premium_command.append('--cli')
+            for line in subprocess.check_output(premium_command).decode('ascii').split('\n'):
+                if line.find('cert-') > 0:
+                    print(line.strip())
+
         data = cppcheckdata.CppcheckData(dumpfile)
 
         if VERIFY:
